;;------------------------------------------------------;;
;;                  VARIABLE DECLARATION                ;;
;;------------------------------------------------------;;

globals
[ 
  price-list
  speed-list
  cache-list 
  best-price
  best-speed
  best-cache   
  
]

turtles-own
[ 
  change-event
  utility-threshold
  utility utility-A utility-B utility-C
  A? B? C? 
  attractiveness-A attractiveness-B attractiveness-C 
  probB probC
  coeff-price coeff-speed coeff-cache coeff-switch
  w-price w-speed w-cache w-switch-cost w-attractiveness
  budget
]  

to setup
  tech-attributes
  ask turtles 
  [ 
    set utility-threshold (1 + random utility-threshold-limit)
    set coeff-price random-normal 1 0.2
    set coeff-speed random-normal 1 0.2
    set coeff-cache random-normal 1 0.2
    set coeff-switch random-normal 1 0.2
    set w-price random-normal 1 0.2
    set w-speed random-normal 1 0.2
    set w-cache random-normal 1 0.2
    set w-switch-cost random-normal 1 0.2
    set w-attractiveness random-normal 1 0.2
    set A? true set B? false set C? false
    set budget random-normal max-initial-budget 20 
  ]   
  
  ask n-of (B-initial * count turtles) turtles
  [
    set color green set A? false set B? true set C? false
  ]
  
  ask n-of (C-initial * count turtles) turtles
  [
    set color blue set A? false set B? false set C? true
  ]
  
  ask turtles
  [
    set change-event random-poisson change-event-limit
    set attractiveness-A count turtles with [color = red] / count turtles
    set attractiveness-B count turtles with [color = green] / count turtles
    set attractiveness-C count turtles with [color = blue] / count turtles
  ]
  
  ask turtles
  [
    compute-utility
  ]
end 

to go
  if count turtles with [color = red] = 0 [stop]
  
  ask turtles
  [
     set budget (budget + random max-budget-increment)
    attractiveness
    compute-utility
  ]
  
  
  ask turtles with [color = red] 
  [ if (ticks >= change-event)
    [
      if (item 1 utility / item 0 utility > utility-threshold) and (budget > (price-B + switch-cost-B)) and (budget < (price-C + switch-cost-C))
        [choose-techB]
      if (item 1 utility / item 0 utility > utility-threshold) and (budget > (price-B + switch-cost-B)) and (budget > (price-C + switch-cost-C)) ; irrational behavior towards C
        [choose-techB_C]
      if (item 2 utility / item 0 utility > utility-threshold) and (budget > (price-C + switch-cost-C)) and (budget < (price-B + switch-cost-B))
        [choose-techC]
      if (item 2 utility / item 0 utility > utility-threshold) and (budget > (price-C + switch-cost-C)) and (budget > (price-B + switch-cost-B)) ; irrational behavior towards B
        [choose-techB_C] 
      if (item 1 utility / item 0 utility > utility-threshold) and (budget > (price-B + switch-cost-B)) and (item 2 utility / item 0 utility > utility-threshold) and (budget > (price-C + switch-cost-C))
        [choose-techB_C]
    ]
  ]
  plot-fractions
  
  tick
end

to tech-attributes
  ;Lists for attributes. Used to compute the best payoff
  set price-list list (price-A) (price-B)
  set price-list lput price-C price-list
  set speed-list list (speed-A) (speed-B)
  set speed-list lput speed-C speed-list
  set cache-list list (cache-A) (cache-B)
  set cache-list lput cache-C cache-list
end

to find-best-option
  ; These are the best options currently available. These are required to normalize the desirability functions
  set best-price min price-list
  set best-speed max speed-list
  set best-cache max cache-list
end

to attractiveness
  let local-attractiveness-A mean [item 0 utility] of link-neighbors * count link-neighbors with [color = red] / count link-neighbors
  let local-attractiveness-B mean [item 1 utility] of link-neighbors * count link-neighbors with [color = green] / count link-neighbors
  let local-attractiveness-C mean [item 2 utility] of link-neighbors * count link-neighbors with [color = blue] / count link-neighbors
  
  set attractiveness-A local-attractiveness-A / (local-attractiveness-A + local-attractiveness-B + local-attractiveness-C)
  set attractiveness-B local-attractiveness-B / (local-attractiveness-A + local-attractiveness-B + local-attractiveness-C)
  set attractiveness-C local-attractiveness-C / (local-attractiveness-A + local-attractiveness-B + local-attractiveness-C)
end

to compute-utility
  ;Compute desirability function. This is needed to compute utilities
  
  let d-price-A ((110 - price-A) / (110 - 80)) ^ coeff-price
  let d-speed-A ((speed-A - 2.33) / (3.33 - 2.33)) ^ coeff-speed
  let d-cache-A ((cache-A - 1) / (6 - 1)) ^ coeff-cache
  let d-switch-cost-A ((100 - switch-cost-A) / (100 - 0)) ^ coeff-switch
  
  let d-price-B ((110 - price-B) / (110 - 80)) ^ coeff-price
  let d-speed-B ((speed-B - 2.33) / (3.33 - 2.33)) ^ coeff-speed
  let d-cache-B ((cache-B - 1) / (6 - 1)) ^ coeff-cache
  let d-switch-cost-B ((100 - switch-cost-B) / (100 - 0)) ^ coeff-switch
  
  let d-price-C ((110 - price-C) / (110 - 80)) ^ coeff-price
  let d-speed-C ((speed-C - 2.33) / (3.33 - 2.33)) ^ coeff-speed
  let d-cache-C ((cache-C - 1) / (6 - 1)) ^ coeff-cache
  let d-switch-cost-C ((100 - switch-cost-C) / (100 - 0)) ^ coeff-switch ; Additional switch cost is not desirable
  
  if utility-function = "Multiplicative"
  [
    set utility-A (d-price-A * d-speed-A * d-cache-A * d-switch-cost-A) ^ 1 / 4 * (attractiveness-A + random-float 0.01) * 100
    set utility-B (d-price-B * d-speed-B * d-cache-B * d-switch-cost-B) ^ 1 / 4 * (attractiveness-B + random-float 0.01) * 100
    set utility-C (d-price-C * d-speed-C * d-cache-C * d-switch-cost-C) ^ 1 / 4 * (attractiveness-C + random-float 0.01) * 100
  ]
  
  if utility-function = "Additive"
  [
    set utility-A (w-price * d-price-A + w-speed * d-speed-A + w-cache * d-cache-A + w-switch-cost * d-switch-cost-A + w-attractiveness * attractiveness-A) / (w-price + w-speed + w-cache + w-switch-cost + w-attractiveness )
    set utility-B (w-price * d-price-B + w-speed * d-speed-B + w-cache * d-cache-B + w-switch-cost * d-switch-cost-B + w-attractiveness * attractiveness-B) / (w-price + w-speed + w-cache + w-switch-cost + w-attractiveness )
    set utility-C (w-price * d-price-C + w-speed * d-speed-C + w-cache * d-cache-C + w-switch-cost * d-switch-cost-C + w-attractiveness * attractiveness-C) / (w-price + w-speed + w-cache + w-switch-cost + w-attractiveness )
  ]
  
  ; List that contains utility of each tech. Can perform list operations such as max min utilities.
  set utility list (utility-A) (utility-B)
  set utility lput utility-C utility
  
  
  ; Probabilistic tech choice. 
  set probB exp( beta * utility-B) / (exp (beta * utility-B) + exp (beta * utility-C))
  set probC exp( beta * utility-C) / (exp (beta * utility-B) + exp (beta * utility-C))
  
end 

to choose-techB
  let prob random-float 1
  if prob < probB
  [set A? false set B? true set C? false set color green ]
  
end

to choose-techC
  
  let prob random-float 1
  if prob < probC
  [set A? false set B? false set C? true set color blue ]  
  
end
to choose-techB_C
  
  let prob random-float 1
  ifelse prob < probB
  [set A? false set B? true set C? false set color green ]
  [set A? false set B? false set C? true set color blue ] 
  
end  



;----------------------------------------------------------------------------------------------------------------
;;;;;;;;;;;;;;
;;;PLOTTING;;;
;;;;;;;;;;;;;;  

to plot-fractions
  set-current-plot "Fractions"
  set-current-plot-pen "tech-A"
  plot ((count turtles with [color =  red])  / (count turtles))  
  set-current-plot-pen "tech-B"
  plot ((count turtles with [color = green])  / (count turtles))
  set-current-plot-pen "tech-C"
  plot ((count turtles with [color = blue])  / (count turtles))
  
end



;------------------------------------------------------------------------------------------------------------------------

;;;;;;;;;;;;;;;;;;;;;;;;
;;; Setup Procedures ;;;
;;;;;;;;;;;;;;;;;;;;;;;;

to start-setup
  clear-all
  set-default-shape turtles "person"
  ;; make the initial network of two turtles and an edge
  make-node nobody        ;; first node, unattached
  make-node turtle 0      ;; second node, attached to first node
end

to setup-network
  ;; new edge is green, old edges are gray
  while [count turtles < population]
  [
    ask links [ set color gray ]
    make-node find-partner         ;; find partner & use it as attachment point for new node
  ]
  if count turtles = population
  [setup]
end

;; used for creating a new node
to make-node [old-node]
  
  crt 1
  [
    set color red
    if old-node != nobody
      [ create-link-with old-node [ set color green ]
        ;; position the new node near its partner
        move-to old-node
        fd 8
      ]
  ]
  ;layout
end

to-report find-partner
  let total random-float sum [count link-neighbors] of turtles
  let partner nobody
  ask turtles
  [
    let nc count link-neighbors
    ;; if there's no winner yet...
    if partner = nobody
    [
      ifelse nc > total
        [ set partner self ]
        [ set total total - nc ]
    ]
  ]
  report partner
end

;;;;;;;;;;;;;;
;;; Layout ;;;
;;;;;;;;;;;;;;

;; resize-nodes, change back and forth from size based on degree to a size of 1
to resize-nodes
  ifelse all? turtles [size <= 1]
  [
    ;; a node is a circle with diameter determined by
    ;; the SIZE variable; using SQRT makes the circle's
    ;; area proportional to its degree
    ask turtles [ set size sqrt count link-neighbors ]
  ]
  [
    ask turtles [ set size 1 ]
  ]
end

to layout
  ;; the number 3 here is arbitrary; more repetitions slows down the
  ;; model, but too few gives poor layouts
  repeat 3 [
    ;; the more turtles we have to fit into the same amount of space,
    ;; the smaller the inputs to layout-spring we'll need to use
    let factor sqrt count turtles
    ;; numbers here are arbitrarily chosen for pleasing appearance
    layout-spring turtles links (1 / factor) (7 / factor) (1 / factor)
    display  ;; for smooth animation
  ]
  ;; don't bump the edges of the world
  let x-offset max [xcor] of turtles + min [xcor] of turtles
  let y-offset max [ycor] of turtles + min [ycor] of turtles
  ;; big jumps look funny, so only adjust a little each time
  set x-offset limit-magnitude x-offset 0.1
  set y-offset limit-magnitude y-offset 0.1
  ask turtles [ setxy (xcor - x-offset / 2) (ycor - y-offset / 2) ]
end

to-report limit-magnitude [number limit]
  if number > limit [ report limit ]
  if number < (- limit) [ report (- limit) ]
  report number
end


;------------------------------------------------------------------------------------------------------------------
@#$#@#$#@
GRAPHICS-WINDOW
292
10
796
535
60
60
4.083
1
10
1
1
1
0
0
0
1
-60
60
-60
60
0
0
1
ticks

BUTTON
41
38
133
71
NIL
start-setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL

SLIDER
816
411
908
444
price-A
price-A
80
110
100
5
1
$
HORIZONTAL

SLIDER
816
449
908
482
price-B
price-B
80
110
100
5
1
$
HORIZONTAL

SLIDER
816
489
908
522
price-C
price-C
80
110
95
5
1
$
HORIZONTAL

SLIDER
916
410
1025
443
speed-A
speed-A
2.33
3.33
2.66
0.05
1
Ghz
HORIZONTAL

SLIDER
917
449
1026
482
speed-B
speed-B
2.33
3.33
2.93
0.05
1
Ghz
HORIZONTAL

SLIDER
917
490
1028
523
speed-C
speed-C
2.33
3.33
3.03
0.05
1
Ghz
HORIZONTAL

SLIDER
1034
410
1126
443
cache-A
cache-A
1
6
2
1
1
NIL
HORIZONTAL

SLIDER
1036
450
1128
483
cache-B
cache-B
1
6
2
1
1
NIL
HORIZONTAL

SLIDER
1036
489
1128
522
cache-C
cache-C
1
6
4
1
1
NIL
HORIZONTAL

BUTTON
42
74
134
107
NIL
setup-network
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL

PLOT
829
66
1189
338
Fractions
NIL
NIL
0.0
10.0
0.0
1.0
true
true
PENS
"tech-A" 1.0 0 -2674135 true
"tech-B" 1.0 0 -10899396 true
"tech-C" 1.0 0 -13345367 true

SLIDER
23
211
115
244
beta
beta
0
15
15
1
1
NIL
HORIZONTAL

BUTTON
41
110
135
143
NIL
layout
T
1
T
OBSERVER
NIL
NIL
NIL
NIL

BUTTON
42
146
135
179
NIL
resize-nodes
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL

TEXTBOX
849
382
894
400
PRICE
11
15.0
1

TEXTBOX
948
382
993
400
SPEED
11
55.0
1

TEXTBOX
1062
382
1106
400
CACHE
11
105.0
1

TEXTBOX
22
187
252
215
Sensitivity to difference in attributes
14
0.0
1

BUTTON
145
146
233
179
NIL
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL

MONITOR
829
10
912
55
Population
count turtles
17
1
11

SLIDER
144
73
236
106
B-initial
B-initial
0
1
0.2
.05
1
NIL
HORIZONTAL

SLIDER
145
109
237
142
C-initial
C-initial
0
1
0.05
.05
1
NIL
HORIZONTAL

MONITOR
915
10
1018
55
% Technology B
count turtles with [color = green] / count turtles
2
1
11

MONITOR
1024
10
1128
55
% Technology C
count turtles with [color = blue] / count turtles
2
1
11

SLIDER
143
38
247
71
population
population
0
5000
2000
50
1
NIL
HORIZONTAL

SLIDER
126
212
254
245
utility-threshold-limit
utility-threshold-limit
0
10
1
1
1
NIL
HORIZONTAL

CHOOSER
92
260
184
305
utility-function
utility-function
"Additive" "Multiplicative"
0

SLIDER
1134
490
1246
523
switch-cost-C
switch-cost-C
0
100
30
10
1
$
HORIZONTAL

SLIDER
1134
450
1244
483
switch-cost-B
switch-cost-B
0
100
0
1
1
$
HORIZONTAL

SLIDER
1132
413
1243
446
switch-cost-A
switch-cost-A
0
100
0
1
1
NIL
HORIZONTAL

SLIDER
157
350
281
383
max-initial-budget
max-initial-budget
0
200
60
10
1
$
HORIZONTAL

SLIDER
6
349
153
382
max-budget-increment
max-budget-increment
1
5
2
1
1
$
HORIZONTAL

SLIDER
85
388
243
421
change-event-limit
change-event-limit
1
100
50
1
1
Time
HORIZONTAL

TEXTBOX
124
10
274
28
Setup
14
0.0
1

TEXTBOX
79
325
275
359
Change Events and Budgets
14
0.0
1

TEXTBOX
866
350
1016
368
Technology Attributes
14
0.0
1

@#$#@#$#@
WHAT IS IT?
-----------
This section could give a general understanding of what the model is trying to show or explain.


HOW IT WORKS
------------
This section could explain what rules the agents use to create the overall behavior of the model.


HOW TO USE IT
-------------
This section could explain how to use the model, including a description of each of the items in the interface tab.


THINGS TO NOTICE
----------------
This section could give some ideas of things for the user to notice while running the model.


THINGS TO TRY
-------------
Attractiveness based on utility rather than average degree node
Different betas


EXTENDING THE MODEL
-------------------
This section could give some ideas of things to add or change in the procedures tab to make the model more complicated, detailed, accurate, etc.


NETLOGO FEATURES
----------------
This section could point out any especially interesting or unusual features of NetLogo that the model makes use of, particularly in the Procedures tab.  It might also point out places where workarounds were needed because of missing features.


RELATED MODELS
--------------
This section could give the names of models in the NetLogo Models Library or elsewhere which are of related interest.


CREDITS AND REFERENCES
----------------------
This section could contain a reference to the model's URL on the web if it has one, as well as any other necessary credits or references.
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
0
Rectangle -7500403 true true 151 225 180 285
Rectangle -7500403 true true 47 225 75 285
Rectangle -7500403 true true 15 75 210 225
Circle -7500403 true true 135 75 150
Circle -16777216 true false 165 76 116

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 4.1.1
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="Fixed-Attribute-Values" repetitions="5" runMetricsEveryStep="false">
    <setup>start-setup
setup-network</setup>
    <go>go</go>
    <timeLimit steps="250"/>
    <metric>(count turtles with [color =  red])  / (count turtles)</metric>
    <metric>(count turtles with [color =  green])  / (count turtles)</metric>
    <metric>(count turtles with [color =  blue])  / (count turtles)</metric>
    <metric>gl</metric>
    <enumeratedValueSet variable="coeff-price-UL">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coeff-speed-UL">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coeff-cache-UL">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coeff-switch-UL">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="B-initial">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="C-initial">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="beta">
      <value value="1"/>
      <value value="5"/>
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="utility-threshold-limit">
      <value value="1"/>
      <value value="2"/>
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="utility-function">
      <value value="&quot;Additive&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-budget-increment">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-initial-budget">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="change-event-limit">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="price-A">
      <value value="95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="price-B">
      <value value="95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="price-C">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="speed-A">
      <value value="3.06"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="speed-B">
      <value value="3.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="speed-C">
      <value value="3.33"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="cache-A">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="cache-B">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="cache-C">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="switch-cost-A">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="switch-cost-B">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="switch-cost-C">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="NPI" repetitions="5" runMetricsEveryStep="false">
    <setup>start-setup
setup-network</setup>
    <go>go</go>
    <timeLimit steps="200"/>
    <metric>(count turtles with [color =  green])  / (count turtles)</metric>
    <metric>(count turtles with [color =  blue])  / (count turtles)</metric>
    <enumeratedValueSet variable="B-initial">
      <value value="0.1"/>
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="price-C">
      <value value="80"/>
      <value value="95"/>
      <value value="110"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="speed-C">
      <value value="2.66"/>
      <value value="3"/>
      <value value="3.33"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="cache-C">
      <value value="2"/>
      <value value="4"/>
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="switch-cost-C">
      <value value="30"/>
      <value value="60"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>count turtles</metric>
    <enumeratedValueSet variable="speed-B">
      <value value="2.93"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-initial-budget">
      <value value="80"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="price-A">
      <value value="105"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="price-B">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="utility-threshold-limit">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="B-initial">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="speed-C">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="switch-cost-C">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="switch-cost-A">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="change-event-limit">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="switch-cost-B">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="cache-C">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="price-C">
      <value value="95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="beta">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="population">
      <value value="2000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="utility-function">
      <value value="&quot;Additive&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-budget-increment">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="cache-B">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="cache-A">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="speed-A">
      <value value="2.98"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="C-initial">
      <value value="0.05"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 1.0 0.0
0.0 1 1.0 0.0
0.2 0 1.0 0.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

@#$#@#$#@
0
@#$#@#$#@
